@@ -17,21 +17,23 @@ class QUOTIENT_API GetWhoIsJob : public BaseJob {
 public:
     // Inner data structures
 
-    struct ConnectionInfo {
+    struct QUOTIENT_API ConnectionInfo {
         //! Most recently seen IP address of the session.
         QString ip{};
+
         //! Unix timestamp that the session was last active.
-        Omittable<qint64> lastSeen{};
+        std::optional<qint64> lastSeen{};
+
         //! User agent string last seen in the session.
         QString userAgent{};
     };
 
-    struct SessionInfo {
+    struct QUOTIENT_API SessionInfo {
         //! Information particular connections in the session.
         QVector<ConnectionInfo> connections{};
     };
 
-    struct DeviceInfo {
+    struct QUOTIENT_API DeviceInfo {
         //! A user's sessions (i.e. what they did with an access token from one login).
         QVector<SessionInfo> sessions{};
     };
@@ -46,43 +48,55 @@ public:
     //!
     //! This function can be used when a URL for GetWhoIsJob
     //! is necessary but the job itself isn't.
-    static QUrl makeRequestUrl(QUrl baseUrl, const QString& userId);
+    static QUrl makeRequestUrl(const HomeserverData& hsData, const QString& userId);
 
     // Result properties
 
     //! The Matrix user ID of the user.
-    QString userId() const { return loadFromJson<QString>("user_id"_ls); }
+    QString userId() const { return loadFromJson<QString>("user_id"_L1); }
 
     //! Each key is an identifier for one of the user's devices.
     QHash<QString, DeviceInfo> devices() const
     {
-        return loadFromJson<QHash<QString, DeviceInfo>>("devices"_ls);
+        return loadFromJson<QHash<QString, DeviceInfo>>("devices"_L1);
     }
+
+    struct Response {
+        //! The Matrix user ID of the user.
+        QString userId{};
+
+        //! Each key is an identifier for one of the user's devices.
+        QHash<QString, DeviceInfo> devices{};
+    };
 };
 
+template <std::derived_from<GetWhoIsJob> JobT>
+constexpr inline auto doCollectResponse<JobT> =
+    [](JobT* j) -> GetWhoIsJob::Response { return { j->userId(), j->devices() }; };
+
 template <>
-struct JsonObjectConverter<GetWhoIsJob::ConnectionInfo> {
+struct QUOTIENT_API JsonObjectConverter<GetWhoIsJob::ConnectionInfo> {
     static void fillFrom(const QJsonObject& jo, GetWhoIsJob::ConnectionInfo& result)
     {
-        fillFromJson(jo.value("ip"_ls), result.ip);
-        fillFromJson(jo.value("last_seen"_ls), result.lastSeen);
-        fillFromJson(jo.value("user_agent"_ls), result.userAgent);
+        fillFromJson(jo.value("ip"_L1), result.ip);
+        fillFromJson(jo.value("last_seen"_L1), result.lastSeen);
+        fillFromJson(jo.value("user_agent"_L1), result.userAgent);
     }
 };
 
 template <>
-struct JsonObjectConverter<GetWhoIsJob::SessionInfo> {
+struct QUOTIENT_API JsonObjectConverter<GetWhoIsJob::SessionInfo> {
     static void fillFrom(const QJsonObject& jo, GetWhoIsJob::SessionInfo& result)
     {
-        fillFromJson(jo.value("connections"_ls), result.connections);
+        fillFromJson(jo.value("connections"_L1), result.connections);
     }
 };
 
 template <>
-struct JsonObjectConverter<GetWhoIsJob::DeviceInfo> {
+struct QUOTIENT_API JsonObjectConverter<GetWhoIsJob::DeviceInfo> {
     static void fillFrom(const QJsonObject& jo, GetWhoIsJob::DeviceInfo& result)
     {
-        fillFromJson(jo.value("sessions"_ls), result.sessions);
+        fillFromJson(jo.value("sessions"_L1), result.sessions);
     }
 };
 
