@@ -25,14 +25,17 @@ class QUOTIENT_API GetAccount3PIDsJob : public BaseJob {
 public:
     // Inner data structures
 
-    struct ThirdPartyIdentifier {
+    struct QUOTIENT_API ThirdPartyIdentifier {
         //! The medium of the third-party identifier.
         QString medium;
+
         //! The third-party identifier address.
         QString address;
+
         //! The timestamp, in milliseconds, when the identifier was
         //! validated by the identity server.
         qint64 validatedAt;
+
         //! The timestamp, in milliseconds, when the homeserver associated the third-party
         //! identifier with the user.
         qint64 addedAt;
@@ -46,24 +49,26 @@ public:
     //!
     //! This function can be used when a URL for GetAccount3PIDsJob
     //! is necessary but the job itself isn't.
-    static QUrl makeRequestUrl(QUrl baseUrl);
+    static QUrl makeRequestUrl(const HomeserverData& hsData);
 
     // Result properties
 
     QVector<ThirdPartyIdentifier> threepids() const
     {
-        return loadFromJson<QVector<ThirdPartyIdentifier>>("threepids"_ls);
+        return loadFromJson<QVector<ThirdPartyIdentifier>>("threepids"_L1);
     }
 };
 
+inline auto collectResponse(const GetAccount3PIDsJob* job) { return job->threepids(); }
+
 template <>
-struct JsonObjectConverter<GetAccount3PIDsJob::ThirdPartyIdentifier> {
+struct QUOTIENT_API JsonObjectConverter<GetAccount3PIDsJob::ThirdPartyIdentifier> {
     static void fillFrom(const QJsonObject& jo, GetAccount3PIDsJob::ThirdPartyIdentifier& result)
     {
-        fillFromJson(jo.value("medium"_ls), result.medium);
-        fillFromJson(jo.value("address"_ls), result.address);
-        fillFromJson(jo.value("validated_at"_ls), result.validatedAt);
-        fillFromJson(jo.value("added_at"_ls), result.addedAt);
+        fillFromJson(jo.value("medium"_L1), result.medium);
+        fillFromJson(jo.value("address"_L1), result.address);
+        fillFromJson(jo.value("validated_at"_L1), result.validatedAt);
+        fillFromJson(jo.value("added_at"_L1), result.addedAt);
     }
 };
 
@@ -79,20 +84,24 @@ struct JsonObjectConverter<GetAccount3PIDsJob::ThirdPartyIdentifier> {
 //! has been removed, making this endpoint behave as though it was `false`.
 //! This results in this endpoint being an equivalent to `/3pid/bind` rather
 //! than dual-purpose.
-class QUOTIENT_API Post3PIDsJob : public BaseJob {
+class [[deprecated("Check the documentation for details")]] QUOTIENT_API Post3PIDsJob
+    : public BaseJob {
 public:
     // Inner data structures
 
     //! The third-party credentials to associate with the account.
-    struct ThreePidCredentials {
+    struct QUOTIENT_API ThreePidCredentials {
         //! The client secret used in the session with the identity server.
         QString clientSecret;
+
         //! The identity server to use.
         QString idServer;
+
         //! An access token previously registered with the identity server. Servers
         //! can treat this as optional to distinguish between r0.5-compatible clients
         //! and this specification version.
         QString idAccessToken;
+
         //! The session identifier given by the identity server.
         QString sid;
     };
@@ -117,19 +126,27 @@ public:
     //! verification will happen without the client's involvement
     //! provided the homeserver advertises this specification version
     //! in the `/versions` response (ie: r0.5.0).
-    QUrl submitUrl() const { return loadFromJson<QUrl>("submit_url"_ls); }
+    QUrl submitUrl() const { return loadFromJson<QUrl>("submit_url"_L1); }
 };
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+inline auto collectResponse(const Post3PIDsJob* job) { return job->submitUrl(); }
+QT_WARNING_POP
+
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template <>
-struct JsonObjectConverter<Post3PIDsJob::ThreePidCredentials> {
+struct QUOTIENT_API JsonObjectConverter<Post3PIDsJob::ThreePidCredentials> {
     static void dumpTo(QJsonObject& jo, const Post3PIDsJob::ThreePidCredentials& pod)
     {
-        addParam<>(jo, QStringLiteral("client_secret"), pod.clientSecret);
-        addParam<>(jo, QStringLiteral("id_server"), pod.idServer);
-        addParam<>(jo, QStringLiteral("id_access_token"), pod.idAccessToken);
-        addParam<>(jo, QStringLiteral("sid"), pod.sid);
+        addParam(jo, "client_secret"_L1, pod.clientSecret);
+        addParam(jo, "id_server"_L1, pod.idServer);
+        addParam(jo, "id_access_token"_L1, pod.idAccessToken);
+        addParam(jo, "sid"_L1, pod.sid);
     }
 };
+QT_WARNING_POP
 
 //! \brief Adds contact information to the user's account.
 //!
@@ -153,7 +170,7 @@ public:
     //!   Additional authentication information for the
     //!   user-interactive authentication API.
     explicit Add3PIDJob(const QString& clientSecret, const QString& sid,
-                        const Omittable<AuthenticationData>& auth = none);
+                        const std::optional<AuthenticationData>& auth = std::nullopt);
 };
 
 //! \brief Binds a 3PID to the user's account through an Identity Service.
@@ -216,10 +233,15 @@ public:
     //! unbind from.
     QString idServerUnbindResult() const
     {
-        return loadFromJson<QString>("id_server_unbind_result"_ls);
+        return loadFromJson<QString>("id_server_unbind_result"_L1);
     }
 };
 
+inline auto collectResponse(const Delete3pidFromAccountJob* job)
+{
+    return job->idServerUnbindResult();
+}
+
 //! \brief Removes a user's third-party identifier from an identity server.
 //!
 //! Removes a user's third-party identifier from the provided identity server
@@ -253,10 +275,15 @@ public:
     //! an identity server to unbind from.
     QString idServerUnbindResult() const
     {
-        return loadFromJson<QString>("id_server_unbind_result"_ls);
+        return loadFromJson<QString>("id_server_unbind_result"_L1);
     }
 };
 
+inline auto collectResponse(const Unbind3pidFromAccountJob* job)
+{
+    return job->idServerUnbindResult();
+}
+
 //! \brief Begins the validation process for an email address for association with the user's
 //! account.
 //!
@@ -281,6 +308,8 @@ public:
     RequestTokenResponse response() const { return fromJson<RequestTokenResponse>(jsonData()); }
 };
 
+inline auto collectResponse(const RequestTokenTo3PIDEmailJob* job) { return job->response(); }
+
 //! \brief Begins the validation process for a phone number for association with the user's account.
 //!
 //! The homeserver must check that the given phone number is **not**
@@ -302,4 +331,6 @@ public:
     RequestTokenResponse response() const { return fromJson<RequestTokenResponse>(jsonData()); }
 };
 
+inline auto collectResponse(const RequestTokenTo3PIDMSISDNJob* job) { return job->response(); }
+
 } // namespace Quotient
