@@ -6,10 +6,11 @@ using namespace Quotient;
 
 UpdateAppserviceRoomDirectoryVisibilityJob::UpdateAppserviceRoomDirectoryVisibilityJob(
     const QString& networkId, const QString& roomId, const QString& visibility)
-    : BaseJob(HttpVerb::Put, QStringLiteral("UpdateAppserviceRoomDirectoryVisibilityJob"),
-              makePath("/_matrix/client/v3", "/directory/list/appservice/", networkId, "/", roomId))
+    : BaseJob(HttpVerb::Put, u"UpdateAppserviceRoomDirectoryVisibilityJob"_s,
+              makePath("/_matrix/client/v3", "/directory/list/appservice/", networkId, "/", roomId),
+              false)
 {
     QJsonObject _dataJson;
-    addParam<>(_dataJson, QStringLiteral("visibility"), visibility);
+    addParam(_dataJson, "visibility"_L1, visibility);
     setRequestData({ _dataJson });
 }
