@@ -4,26 +4,27 @@
 
 using namespace Quotient;
 
-auto queryToGetEventContext(Omittable<int> limit, const QString& filter)
+auto queryToGetEventContext(std::optional<int> limit, const QString& filter)
 {
     QUrlQuery _q;
-    addParam<IfNotEmpty>(_q, QStringLiteral("limit"), limit);
-    addParam<IfNotEmpty>(_q, QStringLiteral("filter"), filter);
+    addParam<IfNotEmpty>(_q, u"limit"_s, limit);
+    addParam<IfNotEmpty>(_q, u"filter"_s, filter);
     return _q;
 }
 
-QUrl GetEventContextJob::makeRequestUrl(QUrl baseUrl, const QString& roomId, const QString& eventId,
-                                        Omittable<int> limit, const QString& filter)
+QUrl GetEventContextJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomId,
+                                        const QString& eventId, std::optional<int> limit,
+                                        const QString& filter)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/rooms/", roomId, "/context/",
                                             eventId),
                                    queryToGetEventContext(limit, filter));
 }
 
 GetEventContextJob::GetEventContextJob(const QString& roomId, const QString& eventId,
-                                       Omittable<int> limit, const QString& filter)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetEventContextJob"),
+                                       std::optional<int> limit, const QString& filter)
+    : BaseJob(HttpVerb::Get, u"GetEventContextJob"_s,
               makePath("/_matrix/client/v3", "/rooms/", roomId, "/context/", eventId),
               queryToGetEventContext(limit, filter))
 {}
