@@ -5,20 +5,21 @@
 using namespace Quotient;
 
 DefineFilterJob::DefineFilterJob(const QString& userId, const Filter& filter)
-    : BaseJob(HttpVerb::Post, QStringLiteral("DefineFilterJob"),
+    : BaseJob(HttpVerb::Post, u"DefineFilterJob"_s,
               makePath("/_matrix/client/v3", "/user/", userId, "/filter"))
 {
     setRequestData({ toJson(filter) });
-    addExpectedKey("filter_id");
+    addExpectedKey(u"filter_id"_s);
 }
 
-QUrl GetFilterJob::makeRequestUrl(QUrl baseUrl, const QString& userId, const QString& filterId)
+QUrl GetFilterJob::makeRequestUrl(const HomeserverData& hsData, const QString& userId,
+                                  const QString& filterId)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl), makePath("/_matrix/client/v3", "/user/",
-                                                                userId, "/filter/", filterId));
+    return BaseJob::makeRequestUrl(hsData, makePath("/_matrix/client/v3", "/user/", userId,
+                                                    "/filter/", filterId));
 }
 
 GetFilterJob::GetFilterJob(const QString& userId, const QString& filterId)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetFilterJob"),
+    : BaseJob(HttpVerb::Get, u"GetFilterJob"_s,
               makePath("/_matrix/client/v3", "/user/", userId, "/filter/", filterId))
 {}
