@@ -5,101 +5,100 @@
 using namespace Quotient;
 
 PostRoomKeysVersionJob::PostRoomKeysVersionJob(const QString& algorithm, const QJsonObject& authData)
-    : BaseJob(HttpVerb::Post, QStringLiteral("PostRoomKeysVersionJob"),
+    : BaseJob(HttpVerb::Post, u"PostRoomKeysVersionJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/version"))
 {
     QJsonObject _dataJson;
-    addParam<>(_dataJson, QStringLiteral("algorithm"), algorithm);
-    addParam<>(_dataJson, QStringLiteral("auth_data"), authData);
+    addParam(_dataJson, "algorithm"_L1, algorithm);
+    addParam(_dataJson, "auth_data"_L1, authData);
     setRequestData({ _dataJson });
-    addExpectedKey("version");
+    addExpectedKey(u"version"_s);
 }
 
-QUrl GetRoomKeysVersionCurrentJob::makeRequestUrl(QUrl baseUrl)
+QUrl GetRoomKeysVersionCurrentJob::makeRequestUrl(const HomeserverData& hsData)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
-                                   makePath("/_matrix/client/v3", "/room_keys/version"));
+    return BaseJob::makeRequestUrl(hsData, makePath("/_matrix/client/v3", "/room_keys/version"));
 }
 
 GetRoomKeysVersionCurrentJob::GetRoomKeysVersionCurrentJob()
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetRoomKeysVersionCurrentJob"),
+    : BaseJob(HttpVerb::Get, u"GetRoomKeysVersionCurrentJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/version"))
 {
-    addExpectedKey("algorithm");
-    addExpectedKey("auth_data");
-    addExpectedKey("count");
-    addExpectedKey("etag");
-    addExpectedKey("version");
+    addExpectedKey(u"algorithm"_s);
+    addExpectedKey(u"auth_data"_s);
+    addExpectedKey(u"count"_s);
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"version"_s);
 }
 
-QUrl GetRoomKeysVersionJob::makeRequestUrl(QUrl baseUrl, const QString& version)
+QUrl GetRoomKeysVersionJob::makeRequestUrl(const HomeserverData& hsData, const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/room_keys/version/", version));
 }
 
 GetRoomKeysVersionJob::GetRoomKeysVersionJob(const QString& version)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetRoomKeysVersionJob"),
+    : BaseJob(HttpVerb::Get, u"GetRoomKeysVersionJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/version/", version))
 {
-    addExpectedKey("algorithm");
-    addExpectedKey("auth_data");
-    addExpectedKey("count");
-    addExpectedKey("etag");
-    addExpectedKey("version");
+    addExpectedKey(u"algorithm"_s);
+    addExpectedKey(u"auth_data"_s);
+    addExpectedKey(u"count"_s);
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"version"_s);
 }
 
 PutRoomKeysVersionJob::PutRoomKeysVersionJob(const QString& version, const QString& algorithm,
                                              const QJsonObject& authData)
-    : BaseJob(HttpVerb::Put, QStringLiteral("PutRoomKeysVersionJob"),
+    : BaseJob(HttpVerb::Put, u"PutRoomKeysVersionJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/version/", version))
 {
     QJsonObject _dataJson;
-    addParam<>(_dataJson, QStringLiteral("algorithm"), algorithm);
-    addParam<>(_dataJson, QStringLiteral("auth_data"), authData);
+    addParam(_dataJson, "algorithm"_L1, algorithm);
+    addParam(_dataJson, "auth_data"_L1, authData);
     setRequestData({ _dataJson });
 }
 
-QUrl DeleteRoomKeysVersionJob::makeRequestUrl(QUrl baseUrl, const QString& version)
+QUrl DeleteRoomKeysVersionJob::makeRequestUrl(const HomeserverData& hsData, const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/room_keys/version/", version));
 }
 
 DeleteRoomKeysVersionJob::DeleteRoomKeysVersionJob(const QString& version)
-    : BaseJob(HttpVerb::Delete, QStringLiteral("DeleteRoomKeysVersionJob"),
+    : BaseJob(HttpVerb::Delete, u"DeleteRoomKeysVersionJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/version/", version))
 {}
 
 auto queryToPutRoomKeyBySessionId(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
 PutRoomKeyBySessionIdJob::PutRoomKeyBySessionIdJob(const QString& roomId, const QString& sessionId,
                                                    const QString& version, const KeyBackupData& data)
-    : BaseJob(HttpVerb::Put, QStringLiteral("PutRoomKeyBySessionIdJob"),
+    : BaseJob(HttpVerb::Put, u"PutRoomKeyBySessionIdJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys/", roomId, "/", sessionId),
               queryToPutRoomKeyBySessionId(version))
 {
     setRequestData({ toJson(data) });
-    addExpectedKey("etag");
-    addExpectedKey("count");
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"count"_s);
 }
 
 auto queryToGetRoomKeyBySessionId(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-QUrl GetRoomKeyBySessionIdJob::makeRequestUrl(QUrl baseUrl, const QString& roomId,
+QUrl GetRoomKeyBySessionIdJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomId,
                                               const QString& sessionId, const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/room_keys/keys/", roomId, "/",
                                             sessionId),
                                    queryToGetRoomKeyBySessionId(version));
@@ -107,7 +106,7 @@ QUrl GetRoomKeyBySessionIdJob::makeRequestUrl(QUrl baseUrl, const QString& roomI
 
 GetRoomKeyBySessionIdJob::GetRoomKeyBySessionIdJob(const QString& roomId, const QString& sessionId,
                                                    const QString& version)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetRoomKeyBySessionIdJob"),
+    : BaseJob(HttpVerb::Get, u"GetRoomKeyBySessionIdJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys/", roomId, "/", sessionId),
               queryToGetRoomKeyBySessionId(version))
 {}
@@ -115,14 +114,14 @@ GetRoomKeyBySessionIdJob::GetRoomKeyBySessionIdJob(const QString& roomId, const
 auto queryToDeleteRoomKeyBySessionId(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-QUrl DeleteRoomKeyBySessionIdJob::makeRequestUrl(QUrl baseUrl, const QString& roomId,
+QUrl DeleteRoomKeyBySessionIdJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomId,
                                                  const QString& sessionId, const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/room_keys/keys/", roomId, "/",
                                             sessionId),
                                    queryToDeleteRoomKeyBySessionId(version));
@@ -131,49 +130,49 @@ QUrl DeleteRoomKeyBySessionIdJob::makeRequestUrl(QUrl baseUrl, const QString& ro
 DeleteRoomKeyBySessionIdJob::DeleteRoomKeyBySessionIdJob(const QString& roomId,
                                                          const QString& sessionId,
                                                          const QString& version)
-    : BaseJob(HttpVerb::Delete, QStringLiteral("DeleteRoomKeyBySessionIdJob"),
+    : BaseJob(HttpVerb::Delete, u"DeleteRoomKeyBySessionIdJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys/", roomId, "/", sessionId),
               queryToDeleteRoomKeyBySessionId(version))
 {
-    addExpectedKey("etag");
-    addExpectedKey("count");
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"count"_s);
 }
 
 auto queryToPutRoomKeysByRoomId(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
 PutRoomKeysByRoomIdJob::PutRoomKeysByRoomIdJob(const QString& roomId, const QString& version,
                                                const RoomKeyBackup& backupData)
-    : BaseJob(HttpVerb::Put, QStringLiteral("PutRoomKeysByRoomIdJob"),
+    : BaseJob(HttpVerb::Put, u"PutRoomKeysByRoomIdJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys/", roomId),
               queryToPutRoomKeysByRoomId(version))
 {
     setRequestData({ toJson(backupData) });
-    addExpectedKey("etag");
-    addExpectedKey("count");
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"count"_s);
 }
 
 auto queryToGetRoomKeysByRoomId(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-QUrl GetRoomKeysByRoomIdJob::makeRequestUrl(QUrl baseUrl, const QString& roomId,
+QUrl GetRoomKeysByRoomIdJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomId,
                                             const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/room_keys/keys/", roomId),
                                    queryToGetRoomKeysByRoomId(version));
 }
 
 GetRoomKeysByRoomIdJob::GetRoomKeysByRoomIdJob(const QString& roomId, const QString& version)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetRoomKeysByRoomIdJob"),
+    : BaseJob(HttpVerb::Get, u"GetRoomKeysByRoomIdJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys/", roomId),
               queryToGetRoomKeysByRoomId(version))
 {}
@@ -181,84 +180,82 @@ GetRoomKeysByRoomIdJob::GetRoomKeysByRoomIdJob(const QString& roomId, const QStr
 auto queryToDeleteRoomKeysByRoomId(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-QUrl DeleteRoomKeysByRoomIdJob::makeRequestUrl(QUrl baseUrl, const QString& roomId,
+QUrl DeleteRoomKeysByRoomIdJob::makeRequestUrl(const HomeserverData& hsData, const QString& roomId,
                                                const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/room_keys/keys/", roomId),
                                    queryToDeleteRoomKeysByRoomId(version));
 }
 
 DeleteRoomKeysByRoomIdJob::DeleteRoomKeysByRoomIdJob(const QString& roomId, const QString& version)
-    : BaseJob(HttpVerb::Delete, QStringLiteral("DeleteRoomKeysByRoomIdJob"),
+    : BaseJob(HttpVerb::Delete, u"DeleteRoomKeysByRoomIdJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys/", roomId),
               queryToDeleteRoomKeysByRoomId(version))
 {
-    addExpectedKey("etag");
-    addExpectedKey("count");
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"count"_s);
 }
 
 auto queryToPutRoomKeys(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-PutRoomKeysJob::PutRoomKeysJob(const QString& version, const QHash<QString, RoomKeyBackup>& rooms)
-    : BaseJob(HttpVerb::Put, QStringLiteral("PutRoomKeysJob"),
-              makePath("/_matrix/client/v3", "/room_keys/keys"), queryToPutRoomKeys(version))
+PutRoomKeysJob::PutRoomKeysJob(const QString& version, const QHash<RoomId, RoomKeyBackup>& rooms)
+    : BaseJob(HttpVerb::Put, u"PutRoomKeysJob"_s, makePath("/_matrix/client/v3", "/room_keys/keys"),
+              queryToPutRoomKeys(version))
 {
     QJsonObject _dataJson;
-    addParam<>(_dataJson, QStringLiteral("rooms"), rooms);
+    addParam(_dataJson, "rooms"_L1, rooms);
     setRequestData({ _dataJson });
-    addExpectedKey("etag");
-    addExpectedKey("count");
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"count"_s);
 }
 
 auto queryToGetRoomKeys(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-QUrl GetRoomKeysJob::makeRequestUrl(QUrl baseUrl, const QString& version)
+QUrl GetRoomKeysJob::makeRequestUrl(const HomeserverData& hsData, const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
-                                   makePath("/_matrix/client/v3", "/room_keys/keys"),
+    return BaseJob::makeRequestUrl(hsData, makePath("/_matrix/client/v3", "/room_keys/keys"),
                                    queryToGetRoomKeys(version));
 }
 
 GetRoomKeysJob::GetRoomKeysJob(const QString& version)
-    : BaseJob(HttpVerb::Get, QStringLiteral("GetRoomKeysJob"),
-              makePath("/_matrix/client/v3", "/room_keys/keys"), queryToGetRoomKeys(version))
+    : BaseJob(HttpVerb::Get, u"GetRoomKeysJob"_s, makePath("/_matrix/client/v3", "/room_keys/keys"),
+              queryToGetRoomKeys(version))
 {
-    addExpectedKey("rooms");
+    addExpectedKey(u"rooms"_s);
 }
 
 auto queryToDeleteRoomKeys(const QString& version)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("version"), version);
+    addParam(_q, u"version"_s, version);
     return _q;
 }
 
-QUrl DeleteRoomKeysJob::makeRequestUrl(QUrl baseUrl, const QString& version)
+QUrl DeleteRoomKeysJob::makeRequestUrl(const HomeserverData& hsData, const QString& version)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
-                                   makePath("/_matrix/client/v3", "/room_keys/keys"),
+    return BaseJob::makeRequestUrl(hsData, makePath("/_matrix/client/v3", "/room_keys/keys"),
                                    queryToDeleteRoomKeys(version));
 }
 
 DeleteRoomKeysJob::DeleteRoomKeysJob(const QString& version)
-    : BaseJob(HttpVerb::Delete, QStringLiteral("DeleteRoomKeysJob"),
+    : BaseJob(HttpVerb::Delete, u"DeleteRoomKeysJob"_s,
               makePath("/_matrix/client/v3", "/room_keys/keys"), queryToDeleteRoomKeys(version))
 {
-    addExpectedKey("etag");
-    addExpectedKey("count");
+    addExpectedKey(u"etag"_s);
+    addExpectedKey(u"count"_s);
 }
