@@ -17,12 +17,14 @@ public:
     //!
     //! This function can be used when a URL for GetJoinedRoomsJob
     //! is necessary but the job itself isn't.
-    static QUrl makeRequestUrl(QUrl baseUrl);
+    static QUrl makeRequestUrl(const HomeserverData& hsData);
 
     // Result properties
 
     //! The ID of each room in which the user has `joined` membership.
-    QStringList joinedRooms() const { return loadFromJson<QStringList>("joined_rooms"_ls); }
+    QStringList joinedRooms() const { return loadFromJson<QStringList>("joined_rooms"_L1); }
 };
 
+inline auto collectResponse(const GetJoinedRoomsJob* job) { return job->joinedRooms(); }
+
 } // namespace Quotient
