@@ -6,11 +6,11 @@ using namespace Quotient;
 
 PostReceiptJob::PostReceiptJob(const QString& roomId, const QString& receiptType,
                                const QString& eventId, const QString& threadId)
-    : BaseJob(HttpVerb::Post, QStringLiteral("PostReceiptJob"),
+    : BaseJob(HttpVerb::Post, u"PostReceiptJob"_s,
               makePath("/_matrix/client/v3", "/rooms/", roomId, "/receipt/", receiptType, "/",
                        eventId))
 {
     QJsonObject _dataJson;
-    addParam<IfNotEmpty>(_dataJson, QStringLiteral("thread_id"), threadId);
+    addParam<IfNotEmpty>(_dataJson, "thread_id"_L1, threadId);
     setRequestData({ _dataJson });
 }
