@@ -6,9 +6,9 @@ using namespace Quotient;
 
 SendMessageJob::SendMessageJob(const QString& roomId, const QString& eventType,
                                const QString& txnId, const QJsonObject& content)
-    : BaseJob(HttpVerb::Put, QStringLiteral("SendMessageJob"),
+    : BaseJob(HttpVerb::Put, u"SendMessageJob"_s,
               makePath("/_matrix/client/v3", "/rooms/", roomId, "/send/", eventType, "/", txnId))
 {
     setRequestData({ toJson(content) });
-    addExpectedKey("event_id");
+    addExpectedKey(u"event_id"_s);
 }
