@@ -7,19 +7,18 @@ using namespace Quotient;
 auto queryToRedirectToSSO(const QString& redirectUrl)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("redirectUrl"), redirectUrl);
+    addParam(_q, u"redirectUrl"_s, redirectUrl);
     return _q;
 }
 
-QUrl RedirectToSSOJob::makeRequestUrl(QUrl baseUrl, const QString& redirectUrl)
+QUrl RedirectToSSOJob::makeRequestUrl(const HomeserverData& hsData, const QString& redirectUrl)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
-                                   makePath("/_matrix/client/v3", "/login/sso/redirect"),
+    return BaseJob::makeRequestUrl(hsData, makePath("/_matrix/client/v3", "/login/sso/redirect"),
                                    queryToRedirectToSSO(redirectUrl));
 }
 
 RedirectToSSOJob::RedirectToSSOJob(const QString& redirectUrl)
-    : BaseJob(HttpVerb::Get, QStringLiteral("RedirectToSSOJob"),
+    : BaseJob(HttpVerb::Get, u"RedirectToSSOJob"_s,
               makePath("/_matrix/client/v3", "/login/sso/redirect"),
               queryToRedirectToSSO(redirectUrl), {}, false)
 {}
@@ -27,19 +26,20 @@ RedirectToSSOJob::RedirectToSSOJob(const QString& redirectUrl)
 auto queryToRedirectToIdP(const QString& redirectUrl)
 {
     QUrlQuery _q;
-    addParam<>(_q, QStringLiteral("redirectUrl"), redirectUrl);
+    addParam(_q, u"redirectUrl"_s, redirectUrl);
     return _q;
 }
 
-QUrl RedirectToIdPJob::makeRequestUrl(QUrl baseUrl, const QString& idpId, const QString& redirectUrl)
+QUrl RedirectToIdPJob::makeRequestUrl(const HomeserverData& hsData, const QString& idpId,
+                                      const QString& redirectUrl)
 {
-    return BaseJob::makeRequestUrl(std::move(baseUrl),
+    return BaseJob::makeRequestUrl(hsData,
                                    makePath("/_matrix/client/v3", "/login/sso/redirect/", idpId),
                                    queryToRedirectToIdP(redirectUrl));
 }
 
 RedirectToIdPJob::RedirectToIdPJob(const QString& idpId, const QString& redirectUrl)
-    : BaseJob(HttpVerb::Get, QStringLiteral("RedirectToIdPJob"),
+    : BaseJob(HttpVerb::Get, u"RedirectToIdPJob"_s,
               makePath("/_matrix/client/v3", "/login/sso/redirect/", idpId),
               queryToRedirectToIdP(redirectUrl), {}, false)
 {}
