@@ -5,11 +5,11 @@
 using namespace Quotient;
 
 SendToDeviceJob::SendToDeviceJob(const QString& eventType, const QString& txnId,
-                                 const QHash<QString, QHash<QString, QJsonObject>>& messages)
-    : BaseJob(HttpVerb::Put, QStringLiteral("SendToDeviceJob"),
+                                 const QHash<UserId, QHash<QString, QJsonObject>>& messages)
+    : BaseJob(HttpVerb::Put, u"SendToDeviceJob"_s,
               makePath("/_matrix/client/v3", "/sendToDevice/", eventType, "/", txnId))
 {
     QJsonObject _dataJson;
-    addParam<>(_dataJson, QStringLiteral("messages"), messages);
+    addParam(_dataJson, "messages"_L1, messages);
     setRequestData({ _dataJson });
 }
