@@ -33,15 +33,17 @@ public:
     QSqlQuery prepareQuery(const QString& queryString) const;
 
     void storeOlmAccount(const QOlmAccount& olmAccount);
-    Omittable<OlmErrorCode> setupOlmAccount(QOlmAccount &olmAccount);
+    std::optional<OlmErrorCode> setupOlmAccount(QOlmAccount &olmAccount);
     void clear();
     void saveOlmSession(const QByteArray& senderKey, const QOlmSession& session,
                         const QDateTime& timestamp);
-    UnorderedMap<QByteArray, std::vector<QOlmSession>> loadOlmSessions();
-    UnorderedMap<QByteArray, QOlmInboundGroupSession> loadMegolmSessions(
+    std::unordered_map<QByteArray, std::vector<QOlmSession>> loadOlmSessions();
+    std::unordered_map<QByteArray, QOlmInboundGroupSession> loadMegolmSessions(
         const QString& roomId);
     void saveMegolmSession(const QString& roomId,
-                           const QOlmInboundGroupSession& session);
+                           const QOlmInboundGroupSession& session,
+                           const QByteArray& senderKey,
+                           const QByteArray& senderClaimedEdKey);
     void addGroupSessionIndexRecord(const QString& roomId,
                                     const QString& sessionId, uint32_t index,
                                     const QString& eventId, qint64 ts);
@@ -51,8 +53,7 @@ public:
     void clearRoomData(const QString& roomId);
     void setOlmSessionLastReceived(const QByteArray& sessionId,
                                    const QDateTime& timestamp);
-    Omittable<QOlmOutboundGroupSession> loadCurrentOutboundMegolmSession(
-        const QString& roomId);
+    std::optional<QOlmOutboundGroupSession> loadCurrentOutboundMegolmSession(const QString& roomId);
     void saveCurrentOutboundMegolmSession(
         const QString& roomId, const QOlmOutboundGroupSession& session);
     void updateOlmSession(const QByteArray& senderKey,
@@ -70,11 +71,18 @@ public:
 
     bool isSessionVerified(const QString& edKey);
     void setSessionVerified(const QString& edKeyId);
+    void setMasterKeyVerified(const QString& masterKey);
 
     QString edKeyForKeyId(const QString& userId, const QString& edKeyId);
     void storeEncrypted(const QString& name, const QByteArray& key);
     QByteArray loadEncrypted(const QString& name);
 
+    QString userSigningPublicKey();
+    QString selfSigningPublicKey();
+
+    QString edKeyForMegolmSession(const QString& sessionId);
+    QString senderKeyForMegolmSession(const QString& sessionId);
+
 private:
     void migrateTo1();
     void migrateTo2();
@@ -82,6 +90,10 @@ private:
     void migrateTo4();
     void migrateTo5();
     void migrateTo6();
+    void migrateTo7();
+    void migrateTo8();
+    void migrateTo9();
+    void migrateTo10();
 
     QString m_userId;
     QString m_deviceId;
