@@ -4,6 +4,8 @@
 #include "encryptedevent.h"
 #include <Quotient/e2ee/e2ee_common.h>
 
+#include "eventrelation.h"
+
 using namespace Quotient;
 
 EncryptedEvent::EncryptedEvent(const QJsonObject& ciphertexts,
@@ -33,27 +35,21 @@ QString EncryptedEvent::algorithm() const
 RoomEventPtr EncryptedEvent::createDecrypted(const QString &decrypted) const
 {
     auto eventObject = QJsonDocument::fromJson(decrypted.toUtf8()).object();
-    eventObject["event_id"_ls] = id();
-    eventObject["sender"_ls] = senderId();
-    eventObject["origin_server_ts"_ls] = originTimestamp().toMSecsSinceEpoch();
-    if (const auto relatesToJson = contentPart<QJsonObject>("m.relates_to"_ls);
+    eventObject["event_id"_L1] = id();
+    eventObject["sender"_L1] = senderId();
+    eventObject["origin_server_ts"_L1] = originTimestamp().toMSecsSinceEpoch();
+    if (const auto relatesToJson = contentPart<QJsonObject>(RelatesToKey);
         !relatesToJson.isEmpty()) {
-        auto content = eventObject["content"_ls].toObject();
-        content["m.relates_to"_ls] = relatesToJson;
-        eventObject["content"_ls] = content;
+        replaceSubvalue(eventObject, ContentKey, RelatesToKey, relatesToJson);
     }
-    if (const auto redactsJson = unsignedPart<QString>("redacts"_ls);
+    if (const auto redactsJson = unsignedPart<QString>("redacts"_L1);
         !redactsJson.isEmpty()) {
-        auto unsign = eventObject["unsigned"_ls].toObject();
-        unsign["redacts"_ls] = redactsJson;
-        eventObject["unsigned"_ls] = unsign;
+        replaceSubvalue(eventObject, UnsignedKey, "redacts"_L1, redactsJson);
     }
     return loadEvent<RoomEvent>(eventObject);
 }
 
 void EncryptedEvent::setRelation(const QJsonObject& relation)
 {
-    auto content = contentJson();
-    content["m.relates_to"_ls] = relation;
-    editJson()["content"_ls] = content;
+    replaceSubvalue(editJson(), ContentKey, RelatesToKey, relation);
 }
