@@ -3,9 +3,12 @@
 
 #pragma once
 
+#include "single_key_value.h"
+
 #include <Quotient/converters.h>
 #include <Quotient/function_traits.h>
-#include "single_key_value.h"
+
+#include <span>
 
 namespace Quotient {
 // === event_ptr_tt<> and basic type casting facilities ===
@@ -13,60 +16,21 @@ namespace Quotient {
 template <typename EventT>
 using event_ptr_tt = std::unique_ptr<EventT>;
 
-template <typename EventT>
-[[deprecated("Use std::to_address() instead")]]
-inline EventT* rawPtr(const event_ptr_tt<EventT>& ptr)
-{
-    return ptr.get();
-}
+// === Standard Matrix key names ===
 
-/// Unwrap a plain pointer and downcast it to the specified type
-template <typename TargetEventT, typename EventT>
-inline TargetEventT* weakPtrCast(const event_ptr_tt<EventT>& ptr)
-{
-    return static_cast<TargetEventT*>(std::to_address(ptr));
-}
-
-// === Standard Matrix key names and basicEventJson() ===
-
-constexpr inline auto TypeKeyL = "type"_ls;
-constexpr inline auto BodyKeyL = "body"_ls;
-constexpr inline auto ContentKeyL = "content"_ls;
-constexpr inline auto EventIdKeyL = "event_id"_ls;
-constexpr inline auto SenderKeyL = "sender"_ls;
-constexpr inline auto RoomIdKeyL = "room_id"_ls;
-constexpr inline auto UnsignedKeyL = "unsigned"_ls;
-constexpr inline auto RedactedCauseKeyL = "redacted_because"_ls;
-constexpr inline auto PrevContentKeyL = "prev_content"_ls;
-constexpr inline auto StateKeyKeyL = "state_key"_ls;
-const QString TypeKey { TypeKeyL };
-const QString BodyKey { BodyKeyL };
-const QString ContentKey { ContentKeyL };
-const QString EventIdKey { EventIdKeyL };
-const QString SenderKey { SenderKeyL };
-const QString RoomIdKey { RoomIdKeyL };
-const QString UnsignedKey { UnsignedKeyL };
-const QString StateKeyKey { StateKeyKeyL };
+constexpr inline auto TypeKey = "type"_L1;
+constexpr inline auto ContentKey = "content"_L1;
+constexpr inline auto SenderKey = "sender"_L1;
+constexpr inline auto UnsignedKey = "unsigned"_L1;
 
 using event_type_t = QLatin1String;
 
-// TODO: Remove in 0.8
-struct QUOTIENT_API EventTypeRegistry {
-    [[deprecated("event_type_t is a string since libQuotient 0.7, use it directly instead")]]
-    static QString getMatrixType(event_type_t typeId);
-
-    EventTypeRegistry() = delete;
-    ~EventTypeRegistry() = default;
-    Q_DISABLE_COPY_MOVE(EventTypeRegistry)
-};
-
 // === EventMetaType ===
 
 class Event;
 
-// TODO: move over to std::derived_from<Event> once it's available everywhere
 template <typename EventT, typename BaseEventT = Event>
-concept EventClass = std::is_base_of_v<BaseEventT, EventT>;
+concept EventClass = std::derived_from<EventT, BaseEventT>;
 
 template <EventClass EventT>
 bool is(const Event& e);
@@ -94,6 +58,7 @@ public:
     }
 
     void addDerived(const AbstractEventMetaType* newType);
+    auto derivedTypes() const { return std::span(_derivedTypes); }
 
     virtual ~AbstractEventMetaType() = default;
 
@@ -108,7 +73,7 @@ protected:
                             Event*& event) const = 0;
 
 private:
-    std::vector<const AbstractEventMetaType*> derivedTypes{};
+    std::vector<const AbstractEventMetaType*> _derivedTypes{};
     Q_DISABLE_COPY_MOVE(AbstractEventMetaType)
 };
 
@@ -185,7 +150,7 @@ private:
             if (EventT::TypeId != type)
                 return false;
         } else {
-            for (const auto& p : derivedTypes) {
+            for (const auto& p : _derivedTypes) {
                 p->doLoadFrom(fullJson, type, event);
                 if (event) {
                     Q_ASSERT(is<EventT>(*event));
@@ -233,7 +198,7 @@ template <EventClass EventT>
 inline event_ptr_tt<EventT> loadEvent(const QJsonObject& fullJson)
 {
     return mostSpecificMetaType<EventT>().loadFrom(
-        fullJson, fullJson[TypeKeyL].toString());
+        fullJson, fullJson[TypeKey].toString());
 }
 
 //! \brief Create an event from a type string and content JSON
@@ -280,21 +245,10 @@ public:
     static QJsonObject basicJson(const QString& matrixType,
                                  const QJsonObject& content)
     {
-        return { { TypeKeyL, matrixType }, { ContentKeyL, content } };
+        return { { TypeKey, matrixType }, { ContentKey, content } };
     }
 
-    //! \brief Event Matrix type, as identified by its metatype object
-    //!
-    //! For generic/unknown events it will contain a descriptive/generic string
-    //! defined by the respective base event type (that can be empty).
-    //! \sa matrixType
-    auto type() const { return metaType().matrixId; }
-
     //! \brief Exact Matrix type stored in JSON
-    //!
-    //! Coincides with the result of type() (but is slower) for events defined
-    //! in C++ (not necessarily in the library); for generic/unknown events
-    //! the returned value will be different.
     QString matrixType() const;
 
     template <EventClass EventT>
@@ -303,11 +257,36 @@ public:
         return Quotient::is<EventT>(*this);
     }
 
-    [[deprecated("Use fullJson() and stringify it with QJsonDocument::toJson() "
-                 "or by other means")]]
-    QByteArray originalJson() const;
-    [[deprecated("Use fullJson() instead")]] //
-    QJsonObject originalJsonObject() const { return fullJson(); }
+    //! \brief Apply one of the visitors based on the actual event type
+    //!
+    //! This function uses function_traits template and is() to find the first
+    //! of the passed visitor invocables that can be called with this event
+    //! object, downcasting `*this` in a type-safe way to the most specific type
+    //! accepted by the visitor. Without this function, you can still write
+    //! a stack of, for example,
+    //! `(else) if (const auto* evtPtr = eventCast<...>(baseEvtPtr))`
+    //! blocks but switchType() provides a more concise and isolating syntax:
+    //! there's no `else` or trailing `return/break` to forget, for one.
+    //! The visitors have to all return the same type (possibly void).
+    //! Here's how you might use this function:
+    //! \code
+    //! RoomEventPtr eptr = /* get the event pointer from somewhere */;
+    //! const auto result = eptr->switchOnType(
+    //!     [](const RoomMemberEvent& memberEvent) {
+    //!         // Do what's needed if eptr points to a RoomMemberEvent
+    //!         return 1;
+    //!     },
+    //!     [](const CallEvent& callEvent) {
+    //!         // Do what's needed if eptr points to a CallEvent or any
+    //!         // class derived from it
+    //!         return 2;
+    //!     },
+    //!     3); /* the default value to return if nothing above matched */
+    //! \endcode
+    //! As the example shows, the last parameter can optionally be
+    //! a plain returned value instead of a visitor.
+    template <typename... VisitorTs>
+    auto switchOnType(VisitorTs&&... visitors) const;
 
     const QJsonObject& fullJson() const { return _json; }
 
@@ -331,13 +310,6 @@ public:
         return fromJson<T>(contentJson()[std::forward<KeyT>(key)]);
     }
 
-    template <typename T>
-    [[deprecated("Use contentPart() to get a part of the event content")]] //
-    T content(const QString& key) const
-    {
-        return contentPart<T>(key);
-    }
-
     const QJsonObject unsignedJson() const;
 
     //! \brief Get a part of the unsigned object, assuming a given type
@@ -353,18 +325,16 @@ public:
 
     friend QUOTIENT_API QDebug operator<<(QDebug dbg, const Event& e)
     {
-        QDebugStateSaver _dss { dbg };
+        const QDebugStateSaver _dss { dbg };
         dbg.noquote().nospace()
             << e.matrixType() << '(' << e.metaType().className << "): ";
         e.dumpTo(dbg);
         return dbg;
     }
 
-    // State events are quite special in Matrix; so isStateEvent() is here,
-    // as an exception. For other base events, Event::is<>() and
-    // Quotient::is<>() should be used; don't add is* methods here
-    bool isStateEvent() const;
-    [[deprecated("Use is<CallEvent>() instead")]] bool isCallEvent() const;
+#if Quotient_VERSION_MAJOR == 0 && Quotient_VERSION_MINOR <= 9
+    [[deprecated("isStateEvent() has moved to RoomEvent")]] bool isStateEvent() const;
+#endif
 
 protected:
     friend class EventMetaType<Event>; // To access the below constructor
@@ -475,15 +445,8 @@ public:
     {                                                                    \
         return MetaType;                                                 \
     }                                                                    \
-    [[deprecated("Use " #CppType_ "::TypeId directly instead")]]         \
-    static constexpr auto matrixTypeId() { return MatrixType_; }         \
-    [[deprecated("Use " #CppType_ "::TypeId directly instead")]]         \
-    static auto typeId() { return TypeId; }                              \
     // End of macro
 
-//! \deprecated This is the old name for what is now known as QUO_EVENT
-#define DEFINE_EVENT_TYPEID(Id_, Type_) QUO_EVENT(Type_, Id_)
-
 #define QUO_CONTENT_GETTER_X(PartType_, PartName_, JsonKey_) \
     PartType_ PartName_() const                              \
     {                                                        \
@@ -497,14 +460,10 @@ public:
 //! <tt>toSnakeCase(PartName_)</tt> (sic) and converts it to the type
 //! \p PartType_. Effectively, the generated method is an equivalent of
 //! \code
-//! contentPart<PartType_>(Quotient::toSnakeCase(#PartName_##_ls));
+//! contentPart<PartType_>(Quotient::toSnakeCase(#PartName_##_L1));
 //! \endcode
 #define QUO_CONTENT_GETTER(PartType_, PartName_) \
-    QUO_CONTENT_GETTER_X(PartType_, PartName_, toSnakeCase(#PartName_##_ls))
-
-//! \deprecated This macro was used after an event class definition
-//! to enable its dynamic loading; it is completely superseded by QUO_EVENT
-#define REGISTER_EVENT_TYPE(Type_)
+    QUO_CONTENT_GETTER_X(PartType_, PartName_, toSnakeCase(#PartName_##_L1))
 
 /// \brief Define a new event class with a single key-value pair in the content
 ///
@@ -514,19 +473,17 @@ public:
 /// To retrieve the value the getter uses a JSON key name that corresponds to
 /// its own (getter's) name but written in snake_case. \p GetterName_ must be
 /// in camelCase, no quotes (an identifier, not a literal).
-#define DEFINE_SIMPLE_EVENT(Name_, Base_, TypeId_, ValueType_, GetterName_,  \
-                            JsonKey_)                                        \
-    constexpr inline auto Name_##ContentKey = JsonKey_##_ls;                 \
-    class QUOTIENT_API Name_                                                 \
-        : public EventTemplate<                                              \
-              Name_, Base_,                                                  \
-              EventContent::SingleKeyValue<ValueType_, Name_##ContentKey>> { \
-    public:                                                                  \
-        QUO_EVENT(Name_, TypeId_)                                            \
-        using value_type = ValueType_;                                       \
-        using EventTemplate::EventTemplate;                                  \
-        QUO_CONTENT_GETTER_X(ValueType_, GetterName_, Name_##ContentKey)     \
-    };                                                                       \
+#define DEFINE_SIMPLE_EVENT(Name_, Base_, TypeId_, ValueType_, GetterName_, JsonKey_)      \
+    constexpr inline auto Name_##ContentKey = JsonKey_##_L1;                               \
+    class QUOTIENT_API Name_                                                               \
+        : public ::Quotient::EventTemplate<                                                \
+              Name_, Base_, EventContent::SingleKeyValue<ValueType_, Name_##ContentKey>> { \
+    public:                                                                                \
+        QUO_EVENT(Name_, TypeId_)                                                          \
+        using value_type = ValueType_;                                                     \
+        using EventTemplate::EventTemplate;                                                \
+        QUO_CONTENT_GETTER_X(ValueType_, GetterName_, Name_##ContentKey)                   \
+    };                                                                                     \
     // End of macro
 
 // === is<>(), eventCast<>() and switchOnType<>() ===
@@ -559,10 +516,10 @@ inline bool is(const Event& e)
 //! the event it must outlive the downcast pointer to keep it from dangling.
 template <EventClass EventT, typename BasePtrT>
 inline auto eventCast(const BasePtrT& eptr)
-    -> decltype(static_cast<EventT*>(&*eptr))
+    -> decltype(static_cast<EventT*>(std::to_address(eptr)))
 {
     return eptr && is<std::decay_t<EventT>>(*eptr)
-               ? static_cast<EventT*>(&*eptr)
+               ? static_cast<EventT*>(std::to_address(eptr))
                : nullptr;
 }
 
@@ -590,11 +547,8 @@ inline auto eventCast(event_ptr_tt<BaseEventT>&& eptr)
 
 namespace _impl {
     template <typename FnT, typename BaseT>
-    concept Invocable_With_Downcast = requires
-    {
-        requires EventClass<BaseT>;
-        std::is_base_of_v<BaseT, std::remove_cvref_t<fn_arg_t<FnT>>>;
-    };
+    concept Invocable_With_Downcast =
+        EventClass<BaseT> && std::derived_from<std::remove_cvref_t<fn_arg_t<FnT>>, BaseT>;
 }
 
 template <EventClass BaseT, typename TailT>
@@ -612,8 +566,8 @@ inline auto switchOnType(const BaseT& event, TailT&& tail)
     }
 }
 
-template <EventClass BaseT, typename FnT1, typename... FnTs>
-inline auto switchOnType(const BaseT& event, FnT1&& fn1, FnTs&&... fns)
+template <typename FnT1, typename... FnTs>
+inline auto switchOnType(const EventClass auto& event, FnT1&& fn1, FnTs&&... fns)
 {
     using event_type1 = fn_arg_t<FnT1>;
     if (is<std::decay_t<event_type1>>(event))
@@ -621,24 +575,13 @@ inline auto switchOnType(const BaseT& event, FnT1&& fn1, FnTs&&... fns)
     return switchOnType(event, std::forward<FnTs>(fns)...);
 }
 
-template <EventClass BaseT, typename... FnTs>
-[[deprecated("The new name for visit() is switchOnType()")]] //
-inline auto visit(const BaseT& event, FnTs&&... fns)
+template <typename... VisitorTs>
+inline auto Event::switchOnType(VisitorTs&&... visitors) const
 {
-    return switchOnType(event, std::forward<FnTs>(fns)...);
+    return Quotient::switchOnType(*this,
+                                  std::forward<VisitorTs>(visitors)...);
 }
 
-    // A facility overload that calls void-returning switchOnType() on each event
-// over a range of event pointers
-// TODO: replace with ranges::for_each once all standard libraries have it
-template <typename RangeT, typename... FnTs>
-inline auto visitEach(RangeT&& events, FnTs&&... fns)
-    requires std::is_void_v<
-        decltype(switchOnType(**begin(events), std::forward<FnTs>(fns)...))>
-{
-    for (auto&& evtPtr: events)
-        switchOnType(*evtPtr, std::forward<FnTs>(fns)...);
-}
 } // namespace Quotient
 Q_DECLARE_METATYPE(Quotient::Event*)
 Q_DECLARE_METATYPE(const Quotient::Event*)
