@@ -50,12 +50,10 @@ public:
     bool isValid() const { return url.isValid(); }
 };
 
-#ifdef Quotient_E2EE_ENABLED
 QUOTIENT_API std::pair<EncryptedFileMetadata, QByteArray> encryptFile(
     const QByteArray& plainText);
 QUOTIENT_API QByteArray decryptFile(const QByteArray& ciphertext,
                                     const EncryptedFileMetadata& metadata);
-#endif
 
 template <>
 struct QUOTIENT_API JsonObjectConverter<EncryptedFileMetadata> {
@@ -71,6 +69,8 @@ struct QUOTIENT_API JsonObjectConverter<JWK> {
 
 using FileSourceInfo = std::variant<QUrl, EncryptedFileMetadata>;
 
+using FileSourceInfoKeys = std::array<QLatin1String, std::variant_size_v<FileSourceInfo>>;
+
 QUOTIENT_API QUrl getUrlFromSourceInfo(const FileSourceInfo& fsi);
 
 QUOTIENT_API void setUrlInSourceInfo(FileSourceInfo& fsi, const QUrl& newUrl);
@@ -88,10 +88,12 @@ void fillJson(QJsonObject&, const FileSourceInfo&) = delete;
 //! - a key-to-object mapping where key is taken from jsonKeys[1] and the object
 //!   is the result of converting EncryptedFileMetadata to JSON,
 //!   if FileSourceInfo stores EncryptedFileMetadata
-QUOTIENT_API void fillJson(QJsonObject& jo,
-                           const std::array<QLatin1String, 2>& jsonKeys,
+QUOTIENT_API void fillJson(QJsonObject& jo, const FileSourceInfoKeys& jsonKeys,
                            const FileSourceInfo& fsi);
 
+QUOTIENT_API FileSourceInfo fileSourceInfoFromJson(const QJsonObject& jo,
+                                                   const FileSourceInfoKeys& jsonKeys);
+
 namespace FileMetadataMap {
     QUOTIENT_API void add(const QString& roomId,
                           const QString& eventId,
