@@ -17,17 +17,31 @@ struct ReplacePair { QLatin1String uriString; char sigil; };
 ///
 /// When there are two prefixes for the same sigil, the first matching
 /// entry for a given sigil is used.
-const ReplacePair replacePairs[] = {
-    { "u/"_ls, '@' },
-    { "user/"_ls, '@' },
-    { "roomid/"_ls, '!' },
-    { "r/"_ls, '#' },
-    { "room/"_ls, '#' },
-    // The notation for bare event ids is not proposed in MSC2312 but there's
-    // https://github.com/matrix-org/matrix-doc/pull/2644
-    { "e/"_ls, '$' },
-    { "event/"_ls, '$' }
-};
+constexpr auto replacePairs = std::to_array<ReplacePair>({ { "u/"_L1, '@' },
+                                                           { "user/"_L1, '@' },
+                                                           { "roomid/"_L1, '!' },
+                                                           { "r/"_L1, '#' },
+                                                           { "room/"_L1, '#' },
+                                                           // This is here to support bare (without
+                                                           // roomid) event ids proposed in MSC2644
+                                                           { "e/"_L1, '$' },
+                                                           { "event/"_L1, '$' } });
+
+inline auto encodedPath(const QUrl& url)
+{
+    return url.path(QUrl::EncodeDelimiters | QUrl::EncodeUnicode);
+}
+
+QString pathSegment(const QUrl& url, int which)
+{
+    return QUrl::fromPercentEncoding(
+        encodedPath(url).section(u'/', which, which).toUtf8());
+}
+
+auto decodeFragmentPart(QStringView part)
+{
+    return QUrl::fromPercentEncoding(part.toLatin1()).toUtf8();
+}
 
 }
 
@@ -36,7 +50,7 @@ Uri::Uri(QByteArray primaryId, QByteArray secondaryId, QString query)
     if (primaryId.isEmpty())
         primaryType_ = Empty;
     else {
-        setScheme("matrix"_ls);
+        setScheme("matrix"_L1);
         QString pathToBe;
         primaryType_ = Invalid;
         if (primaryId.size() < 2) // There should be something after sigil
@@ -56,7 +70,7 @@ Uri::Uri(QByteArray primaryId, QByteArray secondaryId, QString query)
             }
             auto safeSecondaryId = secondaryId.mid(1);
             safeSecondaryId.replace('/', "%2F");
-            pathToBe += "/event/"_ls + QString::fromUtf8(safeSecondaryId);
+            pathToBe += "/event/"_L1 + QString::fromUtf8(safeSecondaryId);
         }
         setPath(pathToBe, QUrl::TolerantMode);
     }
@@ -64,32 +78,6 @@ Uri::Uri(QByteArray primaryId, QByteArray secondaryId, QString query)
         setQuery(query);
 }
 
-static inline auto encodedPath(const QUrl& url)
-{
-    return url.path(QUrl::EncodeDelimiters | QUrl::EncodeUnicode);
-}
-
-static QString pathSegment(const QUrl& url, int which)
-{
-    return QUrl::fromPercentEncoding(
-        encodedPath(url).section(u'/', which, which).toUtf8());
-}
-
-static auto decodeFragmentPart(QStringView part)
-{
-    return QUrl::fromPercentEncoding(part.toLatin1()).toUtf8();
-}
-
-static inline auto matrixToUrlRegexInit()
-{
-    // See https://matrix.org/docs/spec/appendices#matrix-to-navigation
-    const QRegularExpression MatrixToUrlRE {
-        "^/(?<main>[^:]+(:|%3A|%3a)[^/?]+)(/(?<sec>(\\$|%24)[^?]+))?(\\?(?<query>.+))?$"_ls
-    };
-    Q_ASSERT(MatrixToUrlRE.isValid());
-    return MatrixToUrlRE;
-}
-
 Uri::Uri(QUrl url) : QUrl(std::move(url))
 {
     // NB: don't try to use `url` from here on, it's moved-from and empty
@@ -100,15 +88,15 @@ Uri::Uri(QUrl url) : QUrl(std::move(url))
     if (!QUrl::isValid()) // MatrixUri::isValid() checks primaryType_
         return;
 
-    if (scheme() == "matrix"_ls) {
-        // Check sanity as per https://github.com/matrix-org/matrix-doc/pull/2312
+    if (scheme() == "matrix"_L1) {
+        // Check sanity according to MSC2312
         const auto& urlPath = encodedPath(*this);
         const auto& splitPath = urlPath.split(u'/');
         switch (splitPath.size()) {
         case 2:
             break;
         case 4:
-            if (splitPath[2] == "event"_ls || splitPath[2] == "e"_ls)
+            if (splitPath[2] == "event"_L1 || splitPath[2] == "e"_L1)
                 break;
             [[fallthrough]];
         default:
@@ -126,8 +114,10 @@ Uri::Uri(QUrl url) : QUrl(std::move(url))
     }
 
     primaryType_ = NonMatrix; // Default, unless overridden by the code below
-    if (scheme() == "https"_ls && authority() == "matrix.to"_ls) {
-        static const auto MatrixToUrlRE = matrixToUrlRegexInit();
+    if (scheme() == "https"_L1 && authority() == "matrix.to"_L1) {
+        static const QRegularExpression MatrixToUrlRE(
+            "^/(?<main>[^:]+(:|%3A|%3a)[^/?]+)(/(?<sec>(\\$|%24)[^?]+))?(\\?(?<query>.+))?$"_L1);
+        static const auto _ [[maybe_unused]] = QUO_CHECK(MatrixToUrlRE.isValid());
         // matrix.to accepts both literal sigils (as well as & and ? used in
         // its "query" substitute) and their %-encoded forms;
         // so force QUrl to decode everything.
@@ -151,7 +141,7 @@ Uri Uri::fromUserInput(const QString& uriOrId)
     // spec but there's a movement towards making them navigable (see, e.g.,
     // https://github.com/matrix-org/matrix-doc/pull/2644) - so treat them
     // as valid
-    if (QStringLiteral("!@#+$").contains(uriOrId[0]))
+    if ("!@#+$"_L1.contains(uriOrId[0]))
         return Uri { uriOrId.toUtf8() };
 
     return Uri { QUrl::fromUserInput(uriOrId) };
@@ -162,7 +152,7 @@ Uri::Type Uri::type() const { return primaryType_; }
 Uri::SecondaryType Uri::secondaryType() const
 {
     const auto& type2 = pathSegment(*this, 2);
-    return type2 == "event"_ls || type2 == "e"_ls ? EventId : NoSecondaryId;
+    return type2 == "event"_L1 || type2 == "e"_L1 ? EventId : NoSecondaryId;
 }
 
 QUrl Uri::toUrl(UriForm form) const
@@ -174,9 +164,9 @@ QUrl Uri::toUrl(UriForm form) const
         return SLICE(*this, QUrl);
 
     QUrl url;
-    url.setScheme("https"_ls);
-    url.setHost("matrix.to"_ls);
-    url.setPath("/"_ls);
+    url.setScheme("https"_L1);
+    url.setHost("matrix.to"_L1);
+    url.setPath("/"_L1);
     auto fragment = u'/' + primaryId();
     if (const auto& secId = secondaryId(); !secId.isEmpty())
         fragment += u'/' + secId;
@@ -205,13 +195,14 @@ QString Uri::secondaryId() const
     return idStem;
 }
 
-static const auto ActionKey = QStringLiteral("action");
+namespace {
+inline constexpr auto ActionKey = "action"_L1;
+}
 
 QString Uri::action() const
 {
-    return type() == NonMatrix || !isValid()
-               ? QString()
-               : QUrlQuery { query() }.queryItemValue(ActionKey);
+    return type() == NonMatrix || !isValid() ? QString()
+                                             : QUrlQuery{ query() }.queryItemValue(ActionKey);
 }
 
 void Uri::setAction(const QString& newAction)
@@ -228,8 +219,7 @@ void Uri::setAction(const QString& newAction)
 
 QStringList Uri::viaServers() const
 {
-    return QUrlQuery { query() }.allQueryItemValues(QStringLiteral("via"),
-                                                    QUrl::EncodeReserved);
+    return QUrlQuery{ query() }.allQueryItemValues(u"via"_s, QUrl::EncodeReserved);
 }
 
 bool Uri::isValid() const
